@@ -2,7 +2,14 @@ from .account import Account, Identity
 from .attachments import FileAttachment, ItemAttachment
 from .autodiscover import discover
 from .configuration import Configuration
-from .credentials import DELEGATE, IMPERSONATION, Credentials, OAuth2AuthorizationCodeCredentials, OAuth2Credentials
+from .credentials import (
+    DELEGATE,
+    IMPERSONATION,
+    Credentials,
+    OAuth2AuthorizationCodeCredentials,
+    OAuth2Credentials,
+    OAuth2LegacyCredentials,
+)
 from .ewsdatetime import UTC, UTC_NOW, EWSDate, EWSDateTime, EWSTimeZone
 from .extended_properties import ExtendedProperty
 from .folders import DEEP, SHALLOW, Folder, FolderCollection, RootOfHierarchy
@@ -16,6 +23,7 @@ from .items import (
     ForwardItem,
     Message,
     PostItem,
+    PostReplyItem,
     ReplyAllToItem,
     ReplyToItem,
     Task,
@@ -28,71 +36,73 @@ from .settings import OofSettings
 from .transport import BASIC, CBA, DIGEST, GSSAPI, NTLM, OAUTH2, SSPI
 from .version import Build, Version
 
-__version__ = "4.7.2"
+__version__ = "5.0.0"
 
 __all__ = [
     "__version__",
+    "AcceptItem",
     "Account",
-    "Identity",
-    "FileAttachment",
-    "ItemAttachment",
-    "discover",
+    "Attendee",
+    "BASIC",
+    "BaseProtocol",
+    "Body",
+    "Build",
+    "CBA",
+    "CalendarItem",
+    "CancelCalendarItem",
     "Configuration",
-    "DELEGATE",
-    "IMPERSONATION",
+    "Contact",
     "Credentials",
-    "OAuth2AuthorizationCodeCredentials",
-    "OAuth2Credentials",
+    "DEEP",
+    "DELEGATE",
+    "DIGEST",
+    "DLMailbox",
+    "DeclineItem",
+    "DistributionList",
     "EWSDate",
     "EWSDateTime",
     "EWSTimeZone",
-    "UTC",
-    "UTC_NOW",
     "ExtendedProperty",
-    "Folder",
-    "RootOfHierarchy",
-    "FolderCollection",
-    "SHALLOW",
-    "DEEP",
-    "AcceptItem",
-    "TentativelyAcceptItem",
-    "DeclineItem",
-    "CalendarItem",
-    "CancelCalendarItem",
-    "Contact",
-    "DistributionList",
-    "Message",
-    "PostItem",
-    "Task",
-    "ForwardItem",
-    "ReplyToItem",
-    "ReplyAllToItem",
-    "ItemId",
-    "Mailbox",
-    "DLMailbox",
-    "Attendee",
-    "Room",
-    "RoomList",
-    "Body",
-    "HTMLBody",
-    "UID",
     "FailFast",
     "FaultTolerance",
-    "BaseProtocol",
-    "NoVerifyHTTPAdapter",
-    "TLSClientAuth",
-    "OofSettings",
-    "Q",
-    "BASIC",
-    "DIGEST",
-    "NTLM",
+    "FileAttachment",
+    "Folder",
+    "FolderCollection",
+    "ForwardItem",
     "GSSAPI",
-    "SSPI",
+    "HTMLBody",
+    "IMPERSONATION",
+    "Identity",
+    "ItemAttachment",
+    "ItemId",
+    "Mailbox",
+    "Message",
+    "NTLM",
+    "NoVerifyHTTPAdapter",
     "OAUTH2",
-    "CBA",
-    "Build",
+    "OAuth2AuthorizationCodeCredentials",
+    "OAuth2Credentials",
+    "OAuth2LegacyCredentials",
+    "OofSettings",
+    "PostItem",
+    "PostReplyItem",
+    "Q",
+    "ReplyAllToItem",
+    "ReplyToItem",
+    "Room",
+    "RoomList",
+    "RootOfHierarchy",
+    "SHALLOW",
+    "SSPI",
+    "TLSClientAuth",
+    "Task",
+    "TentativelyAcceptItem",
+    "UID",
+    "UTC",
+    "UTC_NOW",
     "Version",
     "close_connections",
+    "discover",
 ]
 
 # Set a default user agent, e.g. "exchangelib/3.1.1 (python-requests/2.22.0)"
